#[switch_vectors]Expand description
Declare header function with signature fn() -> !, which use additional generated code for switching interrupt vectors to the ones from the cell
#[switch_vectors]Declare header function with signature fn() -> !, which use additional generated code for switching interrupt vectors to the ones from the cell